import os

from .consts import CHECKSUM_ALGO_XXH64, SECONDS_IN_MINUTE

CACHE_DEFAULT_DIRNAME = ".cache"
CACHE_DEFAULT_FILENAME = "cache"
CACHE_DEFAULT_PATH = os.path.abspath("./" + CACHE_DEFAULT_DIRNAME)
CACHE_DEFAULT_DIR_LEVEL = 2
CACHE_SEGMENT_SIZE = 2
CACHE_FILE_MIN_SIZE = 2 * 1024
CACHE_MAX_AGE = 30 * SECONDS_IN_MINUTE
CACHE_DEFAULT_ALGORITHM = CHECKSUM_ALGO_XXH64
